@@ -76,7 +76,13 @@ types: list[str] = [
     "AWS::AppMesh::VirtualNode",
     "AWS::AppMesh::VirtualRouter",
     "AWS::AppMesh::VirtualService",
+    "AWS::AppStream::AppBlock",
+    "AWS::AppStream::AppBlockBuilder",
+    "AWS::AppStream::Application",
+    "AWS::AppStream::ApplicationEntitlementAssociation",
+    "AWS::AppStream::ApplicationFleetAssociation",
     "AWS::AppStream::DirectoryConfig",
+    "AWS::AppStream::Entitlement",
     "AWS::AppStream::Fleet",
     "AWS::AppStream::ImageBuilder",
     "AWS::AppStream::Stack",
@@ -168,6 +174,7 @@ types: list[str] = [
     "AWS::CloudFront::AnycastIpList",
     "AWS::CloudFront::CachePolicy",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity",
+    "AWS::CloudFront::ConnectionFunction",
     "AWS::CloudFront::ConnectionGroup",
     "AWS::CloudFront::ContinuousDeploymentPolicy",
     "AWS::CloudFront::Distribution",
@@ -182,6 +189,7 @@ types: list[str] = [
     "AWS::CloudFront::RealtimeLogConfig",
     "AWS::CloudFront::ResponseHeadersPolicy",
     "AWS::CloudFront::StreamingDistribution",
+    "AWS::CloudFront::TrustStore",
     "AWS::CloudFront::VpcOrigin",
     "AWS::CloudTrail::Channel",
     "AWS::CloudTrail::Dashboard",
@@ -356,6 +364,8 @@ types: list[str] = [
     "AWS::EC2::TransitGatewayAttachment",
     "AWS::EC2::TransitGatewayConnect",
     "AWS::EC2::TransitGatewayConnectPeer",
+    "AWS::EC2::TransitGatewayMeteringPolicy",
+    "AWS::EC2::TransitGatewayMeteringPolicyEntry",
     "AWS::EC2::TransitGatewayMulticastDomain",
     "AWS::EC2::TransitGatewayMulticastDomainAssociation",
     "AWS::EC2::TransitGatewayMulticastGroupMember",
@@ -371,12 +381,14 @@ types: list[str] = [
     "AWS::EC2::VPCBlockPublicAccessOptions",
     "AWS::EC2::VPCCidrBlock",
     "AWS::EC2::VPCDHCPOptionsAssociation",
+    "AWS::EC2::VPCEncryptionControl",
     "AWS::EC2::VPCEndpoint",
     "AWS::EC2::VPCEndpointConnectionNotification",
     "AWS::EC2::VPCEndpointService",
     "AWS::EC2::VPCEndpointServicePermissions",
     "AWS::EC2::VPCGatewayAttachment",
     "AWS::EC2::VPCPeeringConnection",
+    "AWS::EC2::VPNConcentrator",
     "AWS::EC2::VPNConnection",
     "AWS::EC2::VPNConnectionRoute",
     "AWS::EC2::VPNGateway",
@@ -388,14 +400,17 @@ types: list[str] = [
     "AWS::EC2::Volume",
     "AWS::EC2::VolumeAttachment",
     "AWS::ECR::PullThroughCacheRule",
+    "AWS::ECR::PullTimeUpdateExclusion",
     "AWS::ECR::RegistryPolicy",
     "AWS::ECR::RegistryScanningConfiguration",
     "AWS::ECR::ReplicationConfiguration",
     "AWS::ECR::Repository",
     "AWS::ECR::RepositoryCreationTemplate",
+    "AWS::ECR::SigningConfiguration",
     "AWS::ECS::CapacityProvider",
     "AWS::ECS::Cluster",
     "AWS::ECS::ClusterCapacityProviderAssociations",
+    "AWS::ECS::ExpressGatewayService",
     "AWS::ECS::PrimaryTaskSet",
     "AWS::ECS::Service",
     "AWS::ECS::TaskDefinition",
@@ -405,6 +420,7 @@ types: list[str] = [
     "AWS::EFS::MountTarget",
     "AWS::EKS::AccessEntry",
     "AWS::EKS::Addon",
+    "AWS::EKS::Capability",
     "AWS::EKS::Cluster",
     "AWS::EKS::FargateProfile",
     "AWS::EKS::IdentityProviderConfig",
@@ -417,8 +433,10 @@ types: list[str] = [
     "AWS::EMR::Step",
     "AWS::EMR::Studio",
     "AWS::EMR::StudioSessionMapping",
+    "AWS::EMR::WALWorkspace",
     "AWS::EMRContainers::VirtualCluster",
     "AWS::EMRServerless::Application",
+    "AWS::EVS::Environment",
     "AWS::ElastiCache::CacheCluster",
     "AWS::ElastiCache::GlobalReplicationGroup",
     "AWS::ElastiCache::ParameterGroup",
@@ -477,6 +495,7 @@ types: list[str] = [
     "AWS::Glue::DataQualityRuleset",
     "AWS::Glue::Database",
     "AWS::Glue::DevEndpoint",
+    "AWS::Glue::IdentityCenterConfiguration",
     "AWS::Glue::Job",
     "AWS::Glue::MLTransform",
     "AWS::Glue::Partition",
@@ -751,6 +770,15 @@ types: list[str] = [
     "AWS::SES::ContactList",
     "AWS::SES::DedicatedIpPool",
     "AWS::SES::EmailIdentity",
+    "AWS::SES::MailManagerAddonInstance",
+    "AWS::SES::MailManagerAddonSubscription",
+    "AWS::SES::MailManagerAddressList",
+    "AWS::SES::MailManagerArchive",
+    "AWS::SES::MailManagerIngressPoint",
+    "AWS::SES::MailManagerRelay",
+    "AWS::SES::MailManagerRuleSet",
+    "AWS::SES::MailManagerTrafficPolicy",
+    "AWS::SES::MultiRegionEndpoint",
     "AWS::SES::ReceiptFilter",
     "AWS::SES::ReceiptRule",
     "AWS::SES::ReceiptRuleSet",
@@ -876,6 +904,7 @@ types: list[str] = [
     "AWS::VerifiedPermissions::PolicyTemplate",
     "AWS::VpcLattice::AccessLogSubscription",
     "AWS::VpcLattice::AuthPolicy",
+    "AWS::VpcLattice::DomainVerification",
     "AWS::VpcLattice::Listener",
     "AWS::VpcLattice::ResourceConfiguration",
     "AWS::VpcLattice::ResourceGateway",
@@ -945,7 +974,7 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
-    "aws-apigateway-domainname.json",
+    "aws-apigateway-domainnameaccessassociation.json",
     "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
@@ -992,7 +1021,13 @@ cached: list[str] = [
     "aws-appmesh-virtualnode.json",
     "aws-appmesh-virtualrouter.json",
     "aws-appmesh-virtualservice.json",
+    "aws-appstream-appblock.json",
+    "aws-appstream-appblockbuilder.json",
+    "aws-appstream-application.json",
+    "aws-appstream-applicationentitlementassociation.json",
+    "aws-appstream-applicationfleetassociation.json",
     "aws-appstream-directoryconfig.json",
+    "aws-appstream-entitlement.json",
     "aws-appstream-fleet.json",
     "aws-appstream-stack.json",
     "aws-appstream-stackfleetassociation.json",
@@ -1016,7 +1051,8 @@ cached: list[str] = [
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
-    "aws-athena-workgroup.json",
+    "aws-athena-namedquery.json",
+    "aws-athena-preparedstatement.json",
     "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
     "aws-autoscaling-lifecyclehook.json",
@@ -1034,6 +1070,7 @@ cached: list[str] = [
     "aws-backupgateway-hypervisor.json",
     "aws-batch-computeenvironment.json",
     "aws-batch-consumableresource.json",
+    "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
@@ -1047,6 +1084,7 @@ cached: list[str] = [
     "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
     "aws-bedrock-promptversion.json",
+    "aws-ce-anomalymonitor.json",
     "aws-ce-anomalysubscription.json",
     "aws-certificatemanager-account.json",
     "aws-certificatemanager-certificate.json",
@@ -1074,6 +1112,7 @@ cached: list[str] = [
     "aws-cloudfront-anycastiplist.json",
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
+    "aws-cloudfront-connectionfunction.json",
     "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
     "aws-cloudfront-distribution.json",
@@ -1087,6 +1126,7 @@ cached: list[str] = [
     "aws-cloudfront-publickey.json",
     "aws-cloudfront-realtimelogconfig.json",
     "aws-cloudfront-responseheaderspolicy.json",
+    "aws-cloudfront-truststore.json",
     "aws-cloudfront-vpcorigin.json",
     "aws-cloudtrail-channel.json",
     "aws-cloudtrail-dashboard.json",
@@ -1255,6 +1295,8 @@ cached: list[str] = [
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
     "aws-ec2-transitgatewayconnectpeer.json",
+    "aws-ec2-transitgatewaymeteringpolicy.json",
+    "aws-ec2-transitgatewaymeteringpolicyentry.json",
     "aws-ec2-transitgatewaymulticastdomain.json",
     "aws-ec2-transitgatewaymulticastdomainassociation.json",
     "aws-ec2-transitgatewaymulticastgroupmember.json",
@@ -1276,25 +1318,30 @@ cached: list[str] = [
     "aws-ec2-vpcblockpublicaccessoptions.json",
     "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
+    "aws-ec2-vpcencryptioncontrol.json",
     "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
     "aws-ec2-vpcendpointservice.json",
     "aws-ec2-vpcendpointservicepermissions.json",
     "aws-ec2-vpcgatewayattachment.json",
     "aws-ec2-vpcpeeringconnection.json",
+    "aws-ec2-vpnconcentrator.json",
     "aws-ec2-vpnconnection.json",
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
     "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
+    "aws-ecr-pulltimeupdateexclusion.json",
     "aws-ecr-registrypolicy.json",
     "aws-ecr-registryscanningconfiguration.json",
     "aws-ecr-replicationconfiguration.json",
     "aws-ecr-repository.json",
     "aws-ecr-repositorycreationtemplate.json",
+    "aws-ecr-signingconfiguration.json",
     "aws-ecs-capacityprovider.json",
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
+    "aws-ecs-expressgatewayservice.json",
     "aws-ecs-primarytaskset.json",
     "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
@@ -1304,10 +1351,10 @@ cached: list[str] = [
     "aws-efs-mounttarget.json",
     "aws-eks-accessentry.json",
     "aws-eks-addon.json",
+    "aws-eks-capability.json",
     "aws-eks-cluster.json",
     "aws-eks-fargateprofile.json",
     "aws-eks-identityproviderconfig.json",
-    "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
     "aws-elasticache-globalreplicationgroup.json",
@@ -1339,6 +1386,7 @@ cached: list[str] = [
     "aws-emr-step.json",
     "aws-emr-studio.json",
     "aws-emr-studiosessionmapping.json",
+    "aws-emr-walworkspace.json",
     "aws-emrcontainers-virtualcluster.json",
     "aws-emrserverless-application.json",
     "aws-events-apidestination.json",
@@ -1351,6 +1399,7 @@ cached: list[str] = [
     "aws-eventschemas-registry.json",
     "aws-eventschemas-registrypolicy.json",
     "aws-eventschemas-schema.json",
+    "aws-evs-environment.json",
     "aws-fis-experimenttemplate.json",
     "aws-fis-targetaccountconfiguration.json",
     "aws-fms-notificationchannel.json",
@@ -1415,7 +1464,6 @@ cached: list[str] = [
     "aws-imagebuilder-component.json",
     "aws-imagebuilder-containerrecipe.json",
     "aws-imagebuilder-distributionconfiguration.json",
-    "aws-imagebuilder-image.json",
     "aws-imagebuilder-imagepipeline.json",
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
@@ -1447,7 +1495,6 @@ cached: list[str] = [
     "aws-lakeformation-tagassociation.json",
     "aws-lambda-alias.json",
     "aws-lambda-codesigningconfig.json",
-    "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
     "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
@@ -1481,7 +1528,6 @@ cached: list[str] = [
     "aws-memorydb-subnetgroup.json",
     "aws-memorydb-user.json",
     "aws-msk-batchscramsecret.json",
-    "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
     "aws-msk-vpcconnection.json",
@@ -1525,7 +1571,6 @@ cached: list[str] = [
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
-    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-pcaconnectorad-connector.json",
     "aws-pcaconnectorad-directoryregistration.json",
@@ -1588,6 +1633,7 @@ cached: list[str] = [
     "aws-rolesanywhere-trustanchor.json",
     "aws-route53-cidrcollection.json",
     "aws-route53-dnssec.json",
+    "aws-route53-healthcheck.json",
     "aws-route53-hostedzone.json",
     "aws-route53-keysigningkey.json",
     "aws-route53-recordset.json",
@@ -1645,6 +1691,7 @@ cached: list[str] = [
     "aws-sagemaker-processingjob.json",
     "aws-sagemaker-project.json",
     "aws-sagemaker-studiolifecycleconfig.json",
+    "aws-sagemaker-userprofile.json",
     "aws-sagemaker-workteam.json",
     "aws-scheduler-schedule.json",
     "aws-scheduler-schedulegroup.json",
@@ -1691,6 +1738,15 @@ cached: list[str] = [
     "aws-ses-contactlist.json",
     "aws-ses-dedicatedippool.json",
     "aws-ses-emailidentity.json",
+    "aws-ses-mailmanageraddoninstance.json",
+    "aws-ses-mailmanageraddonsubscription.json",
+    "aws-ses-mailmanageraddresslist.json",
+    "aws-ses-mailmanagerarchive.json",
+    "aws-ses-mailmanageringresspoint.json",
+    "aws-ses-mailmanagerrelay.json",
+    "aws-ses-mailmanagerruleset.json",
+    "aws-ses-mailmanagertrafficpolicy.json",
+    "aws-ses-multiregionendpoint.json",
     "aws-ses-receiptfilter.json",
     "aws-ses-receiptrule.json",
     "aws-ses-receiptruleset.json",
@@ -1739,7 +1795,9 @@ cached: list[str] = [
     "aws-timestream-influxdbinstance.json",
     "aws-transfer-agreement.json",
     "aws-transfer-certificate.json",
+    "aws-transfer-connector.json",
     "aws-transfer-profile.json",
+    "aws-transfer-server.json",
     "aws-transfer-user.json",
     "aws-transfer-webapp.json",
     "aws-transfer-workflow.json",
@@ -1749,6 +1807,7 @@ cached: list[str] = [
     "aws-verifiedpermissions-policytemplate.json",
     "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
+    "aws-vpclattice-domainverification.json",
     "aws-vpclattice-listener.json",
     "aws-vpclattice-resourceconfiguration.json",
     "aws-vpclattice-resourcegateway.json",
